@@ -21,7 +21,7 @@ from defaultpaths import appdata, commonappdata
 if sys.platform == "win32":
 	from defaultpaths import commonprogramfiles
 elif sys.platform == "darwin":
-	from defaultpaths import appsupport, appsupport_home, prefs, prefs_home
+	from defaultpaths import library, library_home, prefs, prefs_home
 else:
 	from defaultpaths import (xdg_config_dir_default, xdg_config_home, 
 							  xdg_data_home, xdg_data_home_default, 
@@ -92,10 +92,10 @@ else:
 		scale_adjustment_factor = 1.0
 		config_sys = os.path.join(prefs, appname)
 		confighome = os.path.join(prefs_home, appname)
-		datahome = os.path.join(appsupport_home, appname)
+		datahome = os.path.join(appdata, appname)
 		logdir = os.path.join(expanduseru("~"), "Library", 
 							  "Logs", appname)
-		data_dirs += [datahome, os.path.join(appsupport, appname)]
+		data_dirs += [datahome, os.path.join(commonappdata[0], appname)]
 	else:
 		script_ext = ".sh"
 		scale_adjustment_factor = 1.0
@@ -203,9 +203,23 @@ def get_bitmap_as_icon(size, name):
 	return icon
 
 
-def get_display_name():
+def get_argyll_data_dir():
+	if getcfg("argyll.version") < "1.5.0":
+		argyll_data_dirname = "color"
+	else:
+		argyll_data_dirname = "ArgyllCMS"
+	if sys.platform == "darwin" and getcfg("argyll.version") < "1.5.0":
+		return os.path.join(library if is_superuser() else library_home,
+							argyll_data_dirname)
+	else:
+		return os.path.join(commonappdata[0] if is_superuser() else appdata,
+							argyll_data_dirname)
+
+
+def get_display_name(n=None):
 	""" Return name of currently configured display """
-	n = getcfg("display.number") - 1
+	if n is None:
+		n = getcfg("display.number") - 1
 	displays = getcfg("displays").split(os.pathsep)
 	if n >= 0 and n < len(displays):
 		return displays[n].split("@")[0].strip()
@@ -220,6 +234,8 @@ def get_display_number(display_no):
 	except IndexError:
 		pass
 	else:
+		if display == "Web @ localhost":
+			return 0
 		for i in xrange(wx.Display.GetCount()):
 			geometry = "%i, %i, %ix%i" % tuple(wx.Display(i).Geometry)
 			if display.find("@ " + geometry) > -1:
@@ -387,7 +403,9 @@ valid_ranges = {
 	"calibration.black_point_rate": [0.05, 20],
 	"calibration.luminance": [0.000001, 100000],
 	"gamap_default_intent": [0, 3],
+	"measure.uniformity.show_detail": [0, 1],
 	"profile.black_point_compensation": [0, 1],
+	"webserver.portnumber": [1, 65535],
 	"whitepoint.colortemp": [1000, 15000],
 }
 
@@ -401,11 +419,13 @@ valid_values = {
 	# Measurement modes as supported by Argyll -y parameter
 	# 'l' = 'n' (non-refresh-type display, e.g. LCD)
 	# 'c' = 'r' (refresh-type display, e.g. CRT)
-	# We only use 'l' and 'c'
+	# We map 'l' and 'c' to "n" and "r" in
+	# worker.Worker.add_measurement_features if using Argyll >= 1.5
 	# See http://www.argyllcms.com/doc/instruments.html
 	# for description of per-instrument supported modes
-	"measurement_mode": [None, "F", "R", "c", "e", "p", "l", "n", "r", "1", "2",
-						 "3", "4", "5", "6", "7"],
+	"measurement_mode": [None, "B", "F", "L", "R", "a", "b", "c", "e", "f", "g",
+						 "l", "m", "n", "o", "p", "r", "x", "1", "2", "3", "4", 
+						 "5", "6", "7", "8", "9"],
 	"gamap_perceptual_intent": intents,
 	"gamap_saturation_intent": intents,
 	"gamap_src_viewcond": viewconds,
@@ -434,6 +454,7 @@ defaults = {
 	"allow_skip_sensor_cal": 0,
 	"argyll.debug": 0,
 	"argyll.dir": expanduseru("~"), # directory
+	"argyll.version": "0.0.0",
 	"drift_compensation.blacklevel": 0,
 	"drift_compensation.whitelevel": 0,
 	"calibration.ambient_viewcond_adjust": 0,
@@ -446,14 +467,13 @@ defaults = {
 	"calibration.black_point_rate": 4.0,
 	"calibration.black_point_rate.enabled": 0,
 	"calibration.file": None,
+	"calibration.file.previous": None,
 	"calibration.interactive_display_adjustment": 1,
 	"calibration.luminance": 120.0,
 	"calibration.quality": "m",
 	"calibration.update": 0,
 	"colorimeter_correction.testchart": "ccxx.ti1",
 	"colorimeter_correction_matrix_file": "AUTO:",
-	"color.dir": os.path.join(commonappdata[0] if is_superuser() else 
-							  appdata, "color"),
 	"comport.number": 1,
 	# Note: worker.Worker.enumerate_displays_and_ports() overwrites copyright
 	"copyright": "No copyright. Created with %s %s and Argyll CMS" % (appname, 
@@ -489,11 +509,13 @@ defaults = {
 	"measurement_mode.backup": "l",
 	"measurement_mode.highres": 0,
 	"measurement_mode.projector": 0,
+	"measurement.continuous": 0,
 	"measurement.name.expanded": u"",
 	"measurement.play_sound": 1,
 	"measurement.save_path": expanduseru("~"),
 	"measure.darken_background": 0,
 	"measure.darken_background.show_warning": 1,
+	"measure.uniformity.show_detail": 0,
 	"position.x": 50,
 	"position.y": 50,
 	"position.info.x": 50,
@@ -515,6 +537,7 @@ defaults = {
 									# (sys.platform == "win32" and 
 									 # sys.getwindowsversion() >= (6, )) 
 								else "u",  # Linux, OSX
+	"profile.license": "Public Domain",
 	"profile.load_on_login": 1,
 	"profile.name": u" ".join([
 		u"%dns",
@@ -572,6 +595,7 @@ defaults = {
 	"trc.type": "g",
 	"update_check": 1,
 	"use_separate_lut_access": 0,
+	"webserver.portnumber": 8080,
 	"whitepoint.colortemp": 5000,
 	"whitepoint.colortemp.locus": "t",
 	"whitepoint.x": 0.345741,
@@ -741,6 +765,8 @@ def get_current_profile(include_display_profile=False):
 def get_display_profile(display_no=None):
 	if display_no is None:
 		display_no = max(getcfg("display.number") - 1, 0)
+	if get_display_name(display_no) == "Web":
+		return None
 	import ICCProfile as ICCP
 	try:
 		return ICCP.get_display_profile(display_no)
