@@ -20,8 +20,10 @@ from lib.agw.artmanager import ArtManager
 
 from config import (get_data_path, get_icon_bundle, getbitmap, getcfg, setcfg,
 					valid_values)
+from log import get_file_logger
 from meta import name as appname
 from ordereddict import OrderedDict
+from util_str import wrap
 from wxwindows import FlatShadedButton, numpad_keycodes
 import colormath
 import config
@@ -256,45 +258,6 @@ class DisplayAdjustmentImageContainer(labelbook.ImageContainer):
 				buttonRect = wx.Rect(1, pos, modRectWidth, modRectHeight)
 			else:
 				buttonRect = wx.Rect(pos , 1, modRectWidth, modRectHeight)
-
-			# Check if we need to draw a rectangle around the button
-			#if self._nIndex == i:
-			
-				# Set the colours
-				#penColour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_ACTIVECAPTION)
-				#brushColour = ArtManager.Get().LightColour(wx.SystemSettings_GetColour(wx.SYS_COLOUR_ACTIVECAPTION), 75)
-
-				#dc.SetPen(wx.Pen(penColour))
-				#dc.SetBrush(wx.Brush(brushColour))
-
-				## Fix the surrounding of the rect if border is set
-				#if style & INB_BORDER:
-				
-					#if style & INB_TOP or style & INB_BOTTOM:
-						#buttonRect = wx.Rect(buttonRect.x + 1, buttonRect.y, buttonRect.width - 1, buttonRect.height)
-					#else:
-						#buttonRect = wx.Rect(buttonRect.x, buttonRect.y + 1, buttonRect.width, buttonRect.height - 1)
-				
-				#dc.DrawRectangleRect(buttonRect)
-			
-			#if self._nHoeveredImgIdx == i:
-			
-				## Set the colours
-				#penColour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_ACTIVECAPTION)
-				#brushColour = ArtManager.Get().LightColour(wx.SystemSettings_GetColour(wx.SYS_COLOUR_ACTIVECAPTION), 90)
-
-				#dc.SetPen(wx.Pen(penColour))
-				#dc.SetBrush(wx.Brush(brushColour))
-
-				## Fix the surrounding of the rect if border is set
-				#if style & INB_BORDER:
-				
-					#if style & INB_TOP or style & INB_BOTTOM:
-						#buttonRect = wx.Rect(buttonRect.x + 1, buttonRect.y, buttonRect.width - 1, buttonRect.height)
-					#else:
-						#buttonRect = wx.Rect(buttonRect.x, buttonRect.y + 1, buttonRect.width, buttonRect.height - 1)
-				
-				#dc.DrawRectangleRect(buttonRect)
 			
 			if bUseYcoord:
 				rect = wx.Rect(0, pos, rectWidth, rectWidth)
@@ -722,34 +685,6 @@ class DisplayAdjustmentFrame(wx.Frame):
 			self.measurement_sound = wx.Sound(get_data_path("beep.wav") or "")
 		except NotImplementedError:
 			pass
-		#else:
-			## Add option to toggle playing measurement sound on/off
-			#self.add_panel((12, 12), flag=wx.EXPAND)
-			#self.add_panel((12, 12), flag=wx.EXPAND)
-			#self.add_panel((12, 12), flag=wx.EXPAND)
-			#self.add_panel((12, 12), flag=wx.EXPAND)
-			#optionspanel = self.add_panel((12, 12), flag=wx.EXPAND)
-			#optionspanel.SetSizer(wx.BoxSizer(wx.HORIZONTAL))
-			#optionspanel.SetForegroundColour(FGCOLOUR)
-			#self.add_panel((12, 12), flag=wx.EXPAND)
-			#self.measurement_play_sound_ctrl = wx.CheckBox(optionspanel,
-														   #wx.ID_ANY,
-														   #"")
-			#self.measurement_play_sound_ctrl.SetValue(bool(getcfg("measurement.play_sound")))
-			## wxMac won't set color on checkbox label
-			#self.measurement_play_sound_txt = wx.StaticText(optionspanel,
-															#wx.ID_ANY,
-															#lang.getstr("measurement.play_sound"))
-			#self.measurement_play_sound_txt.SetForegroundColour(FGCOLOUR)
-			#self.measurement_play_sound_txt.SetMaxFontSize(10)
-			#self.measurement_play_sound_txt.Bind(wx.EVT_LEFT_UP,
-												 #self.measurement_play_sound_handler)
-			#optionspanel.GetSizer().Add(get_panel(optionspanel, (96, 12)), 1, flag=wx.EXPAND)
-			#optionspanel.GetSizer().Add(self.measurement_play_sound_ctrl,
-										#flag=wx.ALIGN_CENTER_VERTICAL)
-			#optionspanel.GetSizer().Add(self.measurement_play_sound_txt,
-										#flag=wx.LEFT | wx.ALIGN_CENTER_VERTICAL,
-										#border=4)
 		
 		# Add buttons
 		self.btnsizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -822,6 +757,7 @@ class DisplayAdjustmentFrame(wx.Frame):
 		self.Bind(wx.EVT_WINDOW_DESTROY, self.OnDestroy, self)
 		
 		# Final initialization steps
+		self.logger = get_file_logger("adjust")
 		self._setup(True)
 		
 		self.Show()
@@ -869,8 +805,10 @@ class DisplayAdjustmentFrame(wx.Frame):
 	def Pulse(self, msg=""):
 		if ((msg in (lang.getstr("instrument.initializing"),
 					 lang.getstr("instrument.calibrating"),
-					 lang.getstr("please_wait")) or msg == " " * 4 or
-			 "error" in msg.lower() or "failed" in msg.lower()) and
+					 lang.getstr("please_wait"),
+					 lang.getstr("aborting")) or msg == " " * 4 or
+			 "error" in msg.lower() or "failed" in msg.lower() or
+			 msg.startswith(lang.getstr("webserver.waiting"))) and
 			msg != self.lastmsg):
 			self.lastmsg = msg
 			self.Freeze()
@@ -878,8 +816,8 @@ class DisplayAdjustmentFrame(wx.Frame):
 				txt.checkmark.GetContainingSizer().Hide(txt.checkmark)
 				txt.SetLabel(" ")
 			txt = self.lb.GetCurrentPage().txt.values()[0]
-			if txt.GetLabel() != msg:
-				txt.SetLabel(msg)
+			if txt.GetLabel() != wrap(msg, 46):
+				txt.SetLabel(wrap(msg, 46))
 				txt.SetForegroundColour(FGCOLOUR)
 			self.Thaw()
 		return self.keepGoing, False
@@ -906,6 +844,7 @@ class DisplayAdjustmentFrame(wx.Frame):
 		self.lb.AssignImageList(imagelist)
 	
 	def _setup(self, init=False):
+		self.logger.info("-" * 80)
 		self.cold_run = True
 		self.is_busy = None
 		self.is_measuring = None
@@ -1103,24 +1042,9 @@ class DisplayAdjustmentFrame(wx.Frame):
 				  False: FGCOLOUR}
 		if not txt:
 			return
+		self.logger.info("%r" % txt)
 		if "Setting up the instrument" in txt:
 			self.Pulse(lang.getstr("instrument.initializing"))
-		# Argyll CMS < 1.3.6: "Display type is (CRT|LCD)"
-		# Argyll CMS >= 1.3.6: "Display type is '(c|l|n|r|1|2|3|4|5|6|7)'"
-		modes = filter(None, valid_values["measurement_mode"])
-		dtype = re.search("Display type is '?(CRT|LCD|%s)'?".replace(" ", "\s+") % "|".join(modes), txt, re.I)
-		if dtype and dtype.groups()[0][0].lower() != getcfg("measurement_mode"):
-			#print "INFO: Changing mode to", dtype.groups()[0]
-			label = self.lb.GetCurrentPage().txt.values()[0].GetLabel()
-			self.Pulse(" " * 4)
-			mode = dtype.groups()[0]
-			if mode not in modes and mode[0].lower() in modes:
-				mode = mode[0].lower()
-			setcfg("measurement_mode", mode)
-			self.Freeze()
-			self._setup()
-			self.Thaw()
-			self.Pulse(label)
 		
 		if "/ Current" in txt:
 			indicator = getbitmap("theme/icons/10x10/record")
